@@ -1,13 +1,15 @@
 import re
 import html
 
+from typing import List, Tuple, Optional, Union
+
 
 # Conversion code from
 # http://code.activestate.com/recipes/577459-convert-a-youtube-transcript-in-srt-subtitle/
 pat = re.compile(r'<?text start="(\d+\.\d+)" dur="(\d+\.\d+)">(.*)</text>?')
 
 
-def format_srt_time(sec_time):
+def format_srt_time(sec_time: Union[str, float]) -> str:
     """Convert a time in seconds (google's transcript) to srt time format."""
     sec, micro = str(sec_time).split(".")
     m, s = divmod(int(sec), 60)
@@ -15,7 +17,7 @@ def format_srt_time(sec_time):
     return "{:02}:{:02}:{:02},{}".format(h, m, s, micro)
 
 
-def print_srt_line(i, elms):
+def format_srt_line(i: int, elms: Tuple[str, str, str]) -> str:
     """Print a subtitle in srt format."""
     return "{}\n{} --> {}\n{}\n\n".format(
         i,
@@ -25,24 +27,24 @@ def print_srt_line(i, elms):
     )
 
 
-def convert_html(text):
+def convert_html(text: str) -> str:
     return html.unescape(text)
 
 
-def to_srt(buf):
-    out_srt = []
-    buf = "".join(buf.replace("\n", " ")).split("><")
-    i = 0
-    for text in buf:
-        parsed = parse_line(text)
-        if parsed:
+def to_srt(buf: str) -> str:
+    out_srt: List[str] = []
+    srt_data: List[str] = "".join(buf.replace("\n", " ")).split("><")
+    i: int = 0
+    for text in srt_data:
+        parsed: Optional[Tuple[str, str, str]] = parse_line(text)
+        if parsed is not None:
             i += 1
-            out_srt.append(print_srt_line(i, parsed))
+            out_srt.append(format_srt_line(i, parsed))
     out_srt_string = "".join(out_srt)
     return out_srt_string
 
 
-def parse_line(text):
+def parse_line(text: str) -> Optional[Tuple[str, str, str]]:
     """Parse a subtitle."""
     m = re.match(pat, text)
     if m:
